@@ -1,21 +1,10 @@
 /*
- * Copyright 1998-1999 by Matthias Hölzer-Klüpfel <matthias@hoelzer-kluepfel.de>
- * Copyright 2002-2003 by Martin Willers <willers@xm-arts.de>
- * Copyright 2007-2009 by Stefan Böhmann <kde@hilefoks.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 1998-1999 Matthias Hölzer-Klüpfel <matthias@hoelzer-kluepfel.de>
+    SPDX-FileCopyrightText: 2002-2003 Martin Willers <willers@xm-arts.de>
+    SPDX-FileCopyrightText: 2007-2009 Stefan Böhmann <kde@hilefoks.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "toplevel.h"
 #include "timeedit.h"
 #include "settings.h"
@@ -213,7 +202,7 @@ void TopLevel::setTeaList(const QList<Tea> &tealist) {
 void TopLevel::loadTeaMenuItems() {
     int i=0;
 
-    for (const Tea &t : qAsConst(m_tealist)) {
+    for (const Tea &t : std::as_const(m_tealist)) {
         QAction *a = contextMenu()->addAction(
                    i18nc( "%1 - name of the tea, %2 - the predefined time for "
                           "the tea", "%1 (%2)", t.name(), t.timeToString() )
